Munsell100hues55: Chromaticity diagram showing values for x and y for Illuminant A
for 100 hues at 5/5
Description
Munsell100hues55 Chromaticity diagram showing Tristimulus
Values and Trilinear Coordinates for Illuminant A for 100 hues at 5/5.Format
This data frame contains the following columns:
- BookNotation
- Munsell color notation from the Munsell book
- MunsellProductionNo
-
- X
- Tristimulus Value X
- Y
- Tristimulus Value Y
- Z
- Tristimulus Value Z
- x
- Trilinear Coordinate x
- y
- Trilinear Coordinate y
- z
- Trilinear Coordinate z
Hermann VON Schelling, Dean Farnsworth, 1949
Trichromatic Specifications of the Munsell 100 Hues at 5/5 for Illuminant a
Defense Technical Information Center
NAVAL MEDICAL RESEARCH LAB NEW LONDON CONN.References
Hermann VON Schelling, Dean Farnsworth, 1949
Trichromatic Specifications of the Munsell 100 Hues at 5/5 for Illuminant a
Defense Technical Information Center
NAVAL MEDICAL RESEARCH LAB NEW LONDON CONN.
Examples
Run this codedata(Munsell100hues55)
Munsell100hues55
Run the code above in your browser using DataLab