Learn R Programming

colorscience (version 1.0.2)

XYZTannenbaum1974: Approximations from wavelengths to XYZ by Tannenbaum 1974

Description

XYZTannenbaum1974 Approximations from wavelengths to XYZ by Tannenbaum 1974.

Usage

XYZTannenbaum1974(wavelen)

Arguments

wavelen
wavelenght data

Value

XYZ coordinates

Chris Wyman Peter-Pike Sloan Peter Shirley, 2013 Simple Analytic Approximations to the CIE XYZ Color Matching Functions Journal of Computer Graphics Techniques Vol. 2, No. 2

References

Chris Wyman Peter-Pike Sloan Peter Shirley, 2013 Simple Analytic Approximations to the CIE XYZ Color Matching Functions Journal of Computer Graphics Techniques Vol. 2, No. 2

Examples

Run this code
XYZTannenbaum1974(555)

Run the code above in your browser using DataLab