Learn R Programming

colorscience (version 1.0.2)

emittanceblackbodyPlanck: emittance of a black body of temperature T at a given wavelength

Description

emittanceblackbodyPlanck emittance of a black body of temperature T at a given wavelength (in metres).

Usage

emittanceblackbodyPlanck(wlnm, T)

Arguments

wlnm
wavelength in nm
T
temperature in Kelvin

Value

emittance

References

Planck's radiation law https://en.wikipedia.org/wiki/Planck%27s_law

Examples

Run this code
emittanceblackbodyPlanck(555,2000)

Run the code above in your browser using DataLab