tristimulusMunsell: 434 Munsell colors with tristimulus and CMFs for a few illuminants
Description
tristimulusMunsell is a table with 434 Munsell colors with
tristimulus and Color matching functions for illuminants A, C D and S.Format
This data frame contains the following data:
- Munsell
- Munsell color notation
- X.A
- tristimulus X for illuminant A
- Y.A
- tristimulus Y for illuminant A
- Z.A
- tristimulus Z for illuminant A
- x.A
- CMF x for illuminant A
- y.A
- CMF y for illuminant A
- X.C
- tristimulus X for illuminant C
- Y.C
- tristimulus Y for illuminant C
- Z.C
- tristimulus Z for illuminant C
- x.C
- CMF x for illuminant C
- y.C
- CMF y for illuminant C
- X.D
- tristimulus X for illuminant D
- Y.D
- tristimulus Y for illuminant D
- Z.D
- tristimulus Z for illuminant D
- x.D
- CMF x for illuminant D
- y.D
- CMF y for illuminant D
- X.S
- tristimulus for X illuminant S
- Y.S
- tristimulus for Y illuminant S
- Z.S
- tristimulus for Z illuminant S
- x.S
- CMF x for illuminant S
- y.S
- CMF y for illuminant S
- X
- Munsell painting number
K. L. Kelley, K. S. Gibson, and D. Nickerson, 1943
"Tristimulus specification of the Munsell Book of Color from
spectrophotometric measurements,"
J. Opt. Soc. Am. 33, 355–376References
K. L. Kelley, K. S. Gibson, and D. Nickerson, 1943
"Tristimulus specification of the Munsell Book of Color from
spectrophotometric measurements,"
J. Opt. Soc. Am. 33, 355–376
Examples
Run this codedata(tristimulusMunsell)
tristimulusMunsell
Run the code above in your browser using DataLab